/**
 * This is an example of a *sequential* program, i.e., one that does not use
 * any concurrency or parallelism at all. It checks two numbers to see whether
 * they're prime. (It does this in an intentionally inefficient way; there are
 * much better ways to check whether numbers are prime!) See the next program
 * for a version that runs the checks in parallel threads.
 */
public class A_PrimeCheck_Seq {
  public static void main(String[] args) {
    System.out.println("starting...");

    PrimeCheck check1 = new PrimeCheck(93877037L);
    check1.run();

    PrimeCheck check2 = new PrimeCheck(93877039L);
    check2.run();

    System.out.println("done!");
  }
}

/**
 * An object that can check a single number for primality.
 */
class PrimeCheck {
  private long num;

  /**
   * Create a new prime checker for a particular number.
   */
  public PrimeCheck(long n) {
    this.num = n;
  }

  /**
   * Run the primality check and print the result to System.out.
   */
  public void run() {
    // Try every divisor from 2 to num - 1.
    for (long i = 2; i < num; ++i) {
      // If num is divisible by this number, it's not prime.
      if (num % i == 0) {
        System.out.println(num + " is composite: divisible by " + i);
        return;
      }
    }

    // We didn't return yet, so the number is prime.
    System.out.println(num + " is prime!");
  }
}
